import setuptools

setuptools.setup(
    name='Laxcsy_ML',
    version='1.0.0',
    author='LI AOXIN',
    author_email='757918990@qq.com',
    description='get a series of results from default ML',
    packages=setuptools.find_packages(),
    classifiers= [
        'Programming Language :: Python :: 3',
    ]
)